Struct core::ffi::VaListImpl[−][src]

#[repr(transparent)]
pub struct VaListImpl<'f> { /* fields omitted */ }
🔬 This is a nightly-only experimental API. (c_variadic #44930)

the c_variadic feature has not been properly tested on all supported platforms

va_list 的基本实现。

Implementations

🔬 This is a nightly-only experimental API. (c_variadic #44930)

the c_variadic feature has not been properly tested on all supported platforms

将 VaListImpl 转换为与 C 的 va_list 二进制兼容的 VaList。

🔬 This is a nightly-only experimental API. (c_variadic #44930)

the c_variadic feature has not been properly tested on all supported platforms

前进到下一个 arg。

🔬 This is a nightly-only experimental API. (c_variadic #44930)

the c_variadic feature has not been properly tested on all supported platforms

在当前位置复制 va_list。